@@ -7,7 +7,8 @@ import pytest
 
 import act
 import act.tests.sample_files as sample_files
-from act.io import read_gml, read_psl_wind_profiler_temperature
+from act.io import read_gml, read_psl_wind_profiler_temperature, icartt
+from act.io.noaapsl import read_psl_surface_met
 
 
 def test_io():
@@ -507,13 +508,27 @@ def test_read_psl_wind_profiler():
 
 
 def test_read_psl_wind_profiler_temperature():
-    ds = read_psl_wind_profiler_temperature(act.tests.EXAMPLE_NOAA_PSL_TEMPERATURE)
+    ds = read_psl_wind_profiler_temperature(
+        act.tests.EXAMPLE_NOAA_PSL_TEMPERATURE)
 
     ds.attrs['site_identifier'] == 'CTD'
     ds.attrs['elevation'] = 600.0
     ds.T.values[0] == 33.2
 
 
+def test_read_psl_surface_met():
+    ds_object = read_psl_surface_met(sample_files.EXAMPLE_NOAA_PSL_SURFACEMET)
+    assert ds_object.time.size == 2
+    assert np.isclose(np.sum(ds_object['Pressure'].values), 1446.9)
+    assert np.isclose(ds_object['lat'].values, 38.972425)
+    assert ds_object['lat'].attrs['units'] == 'degree_N'
+    assert ds_object['Upward_Longwave_Irradiance'].attrs['long_name'] == 'Upward Longwave Irradiance'
+    assert ds_object['Upward_Longwave_Irradiance'].dtype.str == '<f4'
+
+    with pytest.raises(Exception):
+        ds_object = read_psl_surface_met('aaa22001.00m')
+
+
 def test_read_psl_parsivel():
     url = ['https://downloads.psl.noaa.gov/psd2/data/realtime/DisdrometerParsivel/Stats/ctd/2022/002/ctd2200200_stats.txt',
            'https://downloads.psl.noaa.gov/psd2/data/realtime/DisdrometerParsivel/Stats/ctd/2022/002/ctd2200201_stats.txt',
@@ -524,16 +539,31 @@ def test_read_psl_parsivel():
     assert np.max(obj['number_density_drops'].values) == 355
     assert obj['number_density_drops'].values[10, 10] == 201
 
-    obj = act.io.noaapsl.read_psl_parsivel('https://downloads.psl.noaa.gov/psd2/data/realtime/DisdrometerParsivel/Stats/ctd/2022/002/ctd2200201_stats.txt')
+    obj = act.io.noaapsl.read_psl_parsivel(
+        'https://downloads.psl.noaa.gov/psd2/data/realtime/DisdrometerParsivel/Stats/ctd/2022/002/ctd2200201_stats.txt')
     assert 'number_density_drops' in obj
 
 
 def test_read_psl_fmcw_moment():
     result = act.discovery.download_noaa_psl_data(
-        site='kps', instrument='Radar FMCW Moment', startdate='20220815', hour='06'
+        site='kps', instrument='Radar FMCW Moment',
+        startdate='20220815', hour='06'
     )
     obj = act.io.noaapsl.read_psl_radar_fmcw_moment([result[-1]])
     assert 'range' in obj
-    np.testing.assert_almost_equal(obj['reflectivity_uncalibrated'].mean(), 2.37, decimal=2)
+    np.testing.assert_almost_equal(
+        obj['reflectivity_uncalibrated'].mean(), 2.37, decimal=2)
     assert obj['range'].max() == 10040.
     assert len(obj['time'].values) == 115
+
+
+@pytest.mark.skipif(not act.io.icartt._ICARTT_AVAILABLE,
+                    reason="ICARTT is not installed.")
+def test_read_icartt():
+    result = act.io.icartt.read_icartt(act.tests.EXAMPLE_AAF_ICARTT)
+    assert 'pitch' in result
+    assert len(result['time'].values) == 14087
+    assert result['true_airspeed'].units == 'm/s'
+    assert 'Revision' in result.attrs
+    np.testing.assert_almost_equal(
+        result['static_pressure'].mean(), 708.75, decimal=2)
